[vlmc-devel] commit: Correcting type: Wizzard -> wizard ( Hugo Beauzée-Luyssen )

git at videolan.org git at videolan.org
Wed Apr 14 23:48:35 CEST 2010


vlmc | branch: master | Hugo Beauzée-Luyssen <beauze.h at gmail.com> | Wed Apr 14 23:41:54 2010 +0200| [5d8a83053302e535d631cbad0992035eb751d79d] | committer: Hugo Beauzée-Luyssen 

Correcting type: Wizzard -> wizard

> http://git.videolan.org/gitweb.cgi/vlmc.git/?a=commit;h=5d8a83053302e535d631cbad0992035eb751d79d
---

 src/Gui/MainWindow.cpp |    4 ++--
 src/Gui/MainWindow.h   |    2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/src/Gui/MainWindow.h b/src/Gui/MainWindow.h
index 0a65f62..a45ed81 100644
--- a/src/Gui/MainWindow.h
+++ b/src/Gui/MainWindow.h
@@ -73,7 +73,7 @@ private:
     /**
      *  \brief  Will check if vlmc closed nicely or crashed.
      *          If so, the emergency backup will be opened.
-     *  \return true if a project was restored. If so, the wizzard should
+     *  \return true if a project was restored. If so, the wizard should
      *          not be opened.
      */
     bool        restoreSession();



More information about the Vlmc-devel mailing list
diff --git a/src/Gui/MainWindow.cpp b/src/Gui/MainWindow.cpp
index 7d57327..ef9338b 100644
--- a/src/Gui/MainWindow.cpp
+++ b/src/Gui/MainWindow.cpp
@@ -128,7 +128,7 @@ MainWindow::MainWindow( QWidget *parent ) :
 
     if ( s.value( "ShowWizardStartup", true ).toBool() )
     {
         //If a project was opened from the command line: don't show the wizzard.
         if ( qApp->arguments().size() == 1 )
             m_pWizard->show();
     }
@@ -209,7 +209,7 @@ MainWindow::initVlmcPreferences()
     CREATE_MENU_SHORTCUT( "keyboard/newproject",
                           QKeySequence( QKeySequence::New ).toString().toLocal8Bit(),
                           QT_TRANSLATE_NOOP( "PreferenceWidget", "New project" ),
-                          QT_TRANSLATE_NOOP( "PreferenceWidget", "Open the new project wizzard" ), actionNew_Project );
+                          QT_TRANSLATE_NOOP( "PreferenceWidget", "Open the new project wizard" ), actionNew_Project );
     CREATE_MENU_SHORTCUT( "keyboard/openproject",
                           QKeySequence( QKeySequence::Open ).toString().toLocal8Bit(),
                           QT_TRANSLATE_NOOP( "PreferenceWidget", "Open a project" ),
@@ -128,7 +128,7 @@ MainWindow::MainWindow( QWidget *parent ) :
     if ( s.value( "ShowWizardStartup", true ).toBool() )
     {
-        //If a project was opened from the command line: don't show the wizzard.
+        //If a project was opened from the command line: don't show the wizard.
         if ( qApp->arguments().size() == 1 )
             m_pWizard->show();